# [Django Black Dashboard](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html)

Modern template for **[Django Admin](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html)**, Auth Pages (registration included) crafted on top of **Black Dashboard**, an open-source **Bootstrap** design.

- [Django Admin Black](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html) - Documentation & Support Links
- [Django Black Dashboard](https://app-generator.dev/product/black-dashboard/django/) - The product that uses the library
- [Getting Started with Django](https://app-generator.dev/docs/technologies/django/index.html) - Learn how to code **Django** Projects

<br />

## **Features**

- Design: **[Black Dashboard](https://app-generator.dev/docs/templates/bootstrap/black-dashboard.html)** (Bootstrap)
- **Sections Covered**: 
  - `Admin Section`, reserved for `superusers`
  - `All pages` managed by `Django.contrib.AUTH`
  - `Registration` page
  - `Misc pages`: colors, icons, typography, blank-page 
  
<br />

### Build a Starter with [Django App Generator - Black Design](https://app-generator.dev/tools/django-generator/black/)

- Access the [App Generator](https://app-generator.dev/tools/django-generator/) page
- Select **Black Dashboard** as the preferred design
- (Optional) Design Database: edit models and fields
- (Optional) Edit the fields for the extended user model
- (Optional) Enable OAuth for GitHub
- (Optional) Add Celery (async tasks)
- (Optional) Enable Dynamic API Module
- Docker Scripts
- Render CI/Cd Scripts

**The generated Django project is available as a ZIP Archive and also uploaded to GitHub.**

<br />

![Django Black Dashboard - Modern template for Django Admin Section crafted on top of a modern Bootstrap Design.](https://user-images.githubusercontent.com/51070104/196730732-dda1794b-93ce-48cb-bc5c-182411495512.png)

<br />

## [Black Dashboard PRO Version](https://app-generator.dev/product/black-dashboard-pro/django/)

> The premium version provides more features, priority on support, and is more often updated - [Live Demo](https://django-black-pro.onrender.com).

- **Simple, Easy-to-Extend** Codebase
- **Black Dashboard** Design - PRO Version
- Bootstrap 4 CSS
- **OAuth** - Github
- **Extended User Profile**
- **API** via DRF 
- **Charts** via ApexJS 
- **Celery** (async tasks)
- **Deployment-Ready** for Render 

![Django Black PRO - Premium Django starter built with Black Dashboard design from Creative-Tim](https://github.com/user-attachments/assets/63c1ea5b-6c8b-4e67-8e07-156c3e06895f)

<br />

---
**[Django Black Dashboard](https://app-generator.dev/docs/products/django-libs/theme-black-dashboard.html)** - Modern Django Admin Interface provided by **[App-Generator](https://app-generator.dev)**
